# Enable or disable running the tests
%global tests 0

%global __brp_mangle_shebangs_exclude_from .*ssh/askpass\.py

Name:           kitty
Version:        0.34.1
Release:        %mkrel 1
Summary:        A cross-platform, fast, feature full, GPU based terminal emulator
Group:          Terminals
License:        GPLv3
URL:            https://sw.kovidgoyal.net/kitty/
Source0:        https://github.com/kovidgoyal/kitty/releases/download/v%{version}/%{name}-%{version}.tar.xz
# kitty.conf created by kekepower.
# Default is located in /etc/xdg/kitty/kitty.conf
Source1:        kitty.conf
# Go vendor source for kitty
Source2:        kitty-%{version}-go-vendor.tar.gz

Patch1:         kitty-0.27.0-extend-ldflags.patch

#
# Security patches
# P100 -> ...

BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  fontconfig
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  python3dist(pillow)
BuildRequires:  wayland-devel
BuildRequires:  wayland-protocols-devel
BuildRequires:  wayland-tools
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  rsync-devel
BuildRequires:  pkgconfig(openssl)
BuildRequires:  git-core
BuildRequires:  golang
BuildRequires:  pkgconfig(libxxhash)
BuildRequires:  pkgconfig(simde)
%if %{tests}
# This is required to run the tests
BuildRequires:  texlive-fontsextra
%endif
# ImageMagick is needed to resize the app icon to all sizes
BuildRequires:  graphicsmagick

Requires:       harfbuzz
Requires:       freetype2
Requires:       fontconfig
Requires:       %{_lib}canberra-gtk3_0
Requires:       imagemagick
Requires:       python3dist(pygments)
Requires:       %{name}-terminfo = %{version}-%{release}
Recommends:     %{name}-docs = %{version}-%{release}

%description
kitty is a cross-platform, fast, feature full, GPU based terminal emulator.

It is designed for power keyboard users. To that end all its controls work
with the keyboard (although it fully supports mouse interactions as well).
Its configuration is a simple, human editable, single file for easy
reproducibility (I like to store configuration in source control).

Finally, kitty is designed from the ground up to support all modern terminal
features, such as unicode, true color, bold/italic fonts, text formatting,
etc. It even extends existing text formatting escape codes, to add support
for features not available elsewhere, such as colored and styled (curly)
underlines. One of the design goals of kitty is to be easily extensible so
that new features can be added in the future with relatively little effort.

%package terminfo
Summary:       Terminfo for %{name}
Group:         Terminals
License:       GPLv3
BuildArch:     noarch

%description terminfo
Terminal info for %{name}.

You can install this package on, for example, servers you want to log on to
remotely to enable all the features available in %{name} without having to
install the whole program.

%package docs
Summary:       Documentation for %{name}
Group:         Terminals
License:       GPLv3
BuildArch:     noarch

%Description docs
%{summary}.

%prep
%autosetup -S git -a2

%build
# We want to control when to update this package and that is done with the
# option "--update-check-interval=0"
%{__python3} setup.py linux-package \
    --prefix %{_real_vendor}-%{_arch} \
    --update-check-interval=0 \
    --verbose \
    --debug \
    --libdir-name %{_lib}

# Fix the path to Python 3
%py3_shebang_fix %{_real_vendor}-%{_arch}/%{_lib}/kitty/

# Convert the app icon to all the sizes
mkdir -p %{_real_vendor}-%{_arch}/share/icons/hicolor/16x16/apps
mkdir -p %{_real_vendor}-%{_arch}/share/icons/hicolor/32x32/apps
mkdir -p %{_real_vendor}-%{_arch}/share/icons/hicolor/64x64/apps
mkdir -p %{_real_vendor}-%{_arch}/share/icons/hicolor/128x128/apps
mkdir -p %{_real_vendor}-%{_arch}/share/icons/hicolor/256x256/apps
mkdir -p %{_real_vendor}-%{_arch}/share/icons/hicolor/512x512/apps

%{_bindir}/gm convert logo/kitty.iconset/icon_512x512.png \
  -resize 64x64 logo/kitty.iconset/icon_64x64.png
cp logo/kitty.iconset/icon_16x16.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/16x16/apps/%{name}.png
cp logo/kitty.iconset/icon_32x32.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/32x32/apps/%{name}.png
cp logo/kitty.iconset/icon_64x64.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/64x64/apps/%{name}.png
cp logo/kitty.iconset/icon_128x128.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/128x128/apps/%{name}.png
cp logo/kitty.iconset/icon_256x256.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/256x256/apps/%{name}.png
cp logo/kitty.iconset/icon_512x512.png \
  %{_real_vendor}-%{_arch}/share/icons/hicolor/512x512/apps/%{name}.png

%install
mkdir -p %{buildroot}%{_prefix}
cp -af %{_real_vendor}-%{_arch}/* %{buildroot}%{_prefix}

mkdir -p %{buildroot}%{_sysconfdir}/xdg/%{name}
cp %{S:1} %{buildroot}%{_sysconfdir}/xdg/%{name}/%{name}.conf

#mkdir -p %{buildroot}/%{_mandir}/man5
#mv %{buildroot}/%{_mandir}/man1/*5* %{buildroot}/%{_mandir}/man5/

%if %{tests}
%check
%{__python3} setup.py test
%endif

%files
%license LICENSE
%doc README.asciidoc
%{_bindir}/%{name}
%{_bindir}/kitten
%{_datadir}/applications/%{name}*.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_libdir}/%{name}/
%config(noreplace) %{_sysconfdir}/xdg/%{name}/%{name}.conf
%exclude %{_mandir}/man1/%{name}*
%exclude %{_datadir}/doc/%{name}/html/
%exclude %{_datadir}/terminfo/x/xterm-kitty

%files docs
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/kitten*
%{_mandir}/man5/%{name}*
%{_datadir}/doc/%{name}/html/


%files terminfo
%{_datadir}/terminfo/x/xterm-kitty


%changelog
* Sat Apr 20 2024 kekepower <kekepower> 0.34.1-1.mga10
+ Revision: 2059935
- Update to version 0.34.1

* Mon Apr 15 2024 kekepower <kekepower> 0.34.0-1.mga10
+ Revision: 2057707
- Update to version 0.34.0

* Sat Mar 23 2024 kekepower <kekepower> 0.33.1-1.mga10
+ Revision: 2051553
- Update to version 0.33.1

* Thu Mar 14 2024 kekepower <kekepower> 0.33.0-3.mga10
+ Revision: 2049872
- Add another upstream patch to fix build on armv7hl

* Thu Mar 14 2024 kekepower <kekepower> 0.33.0-2.mga10
+ Revision: 2049857
- Add upstream patch to fix build on armv7hl

* Thu Mar 14 2024 kekepower <kekepower> 0.33.0-1.mga10
+ Revision: 2049825
- Update to version 0.33.0

* Mon Feb 12 2024 kekepower <kekepower> 0.32.2-1.mga10
+ Revision: 2040497
- Update to version 0.32.2

* Sun Jan 21 2024 kekepower <kekepower> 0.32.0-1.mga10
+ Revision: 2033083
- Upstream patch to fix build breakage on arm and i586
- Update to version 0.32.0

* Fri Nov 10 2023 kekepower <kekepower> 0.31.0-3.mga10
+ Revision: 2005675
- Use GraphicsMagick instead of imagemagick to convert images during build
- Bump rel again for a rebuild
- Bump rel for rebuild
- Update to version 0.31.0

* Mon Oct 09 2023 kekepower <kekepower> 0.30.1-1.mga10
+ Revision: 1993754
- Update to version 0.30.1

* Mon Sep 18 2023 kekepower <kekepower> 0.30.0-1.mga10
+ Revision: 1987829
- Update to version 0.30.0

* Mon Aug 28 2023 kekepower <kekepower> 0.29.2-1.mga10
+ Revision: 1980628
- Update to version 0.29.2

* Tue Jun 27 2023 neoclust <neoclust> 0.28.1-2.mga9
+ Revision: 1963175
- Add P100: Fixes security issue (mga#31941)

* Fri Apr 21 2023 kekepower <kekepower> 0.28.1-1.mga9
+ Revision: 1953842
- Update to version 0.28.1

* Sat Apr 15 2023 kekepower <kekepower> 0.28.0-1.mga9
+ Revision: 1953042
- Update to version 0.28.0
- Remove merged patch
- Update to version 0.27.1

* Tue Jan 31 2023 kekepower <kekepower> 0.27.0-1.mga9
+ Revision: 1937182
- Update to version 0.27.0

* Tue Dec 20 2022 kekepower <kekepower> 0.26.5-2.mga9
+ Revision: 1925402
- Add upstream patch to fix soft-wrap bug
  o See https://github.com/kovidgoyal/kitty/issues/5766

* Mon Nov 07 2022 kekepower <kekepower> 0.26.5-1.mga9
+ Revision: 1904490
- Update to version 0.26.5

* Mon Oct 17 2022 kekepower <kekepower> 0.26.4-1.mga9
+ Revision: 1897199
- Update to version 0.26.4

* Thu Sep 22 2022 kekepower <kekepower> 0.26.3-1.mga9
+ Revision: 1891523
- Update to version 0.26.3

* Mon Sep 05 2022 kekepower <kekepower> 0.26.2-1.mga9
+ Revision: 1884258
- Update to version 0.26.2

* Mon Aug 29 2022 kekepower <kekepower> 0.26.1-1.mga9
+ Revision: 1881986
- Update to version 0.26.1

* Mon Aug 29 2022 kekepower <kekepower> 0.26.0-1.mga9
+ Revision: 1881647
- Add OpenSSL-devel BuildRequire
- Update to version 0.26.0

* Wed Jun 08 2022 kekepower <kekepower> 0.25.2-1.mga9
+ Revision: 1863564
- Update to version 0.25.2

* Thu May 26 2022 kekepower <kekepower> 0.25.1-1.mga9
+ Revision: 1860198
- Update to version 0.25.1

* Thu Apr 14 2022 kekepower <kekepower> 0.25.0-2.mga9
+ Revision: 1849867
- Fix installation issue thanks to wally

* Mon Apr 11 2022 kekepower <kekepower> 0.25.0-1.mga9
+ Revision: 1848864
- Update to version 0.25.0

* Wed Apr 06 2022 umeabot <umeabot> 0.24.4-2.mga9
+ Revision: 1845999
- Mageia 9 Mass Rebuild

* Thu Mar 03 2022 kekepower <kekepower> 0.24.4-1.mga9
+ Revision: 1788003
- Update to version 0.24.4

* Mon Feb 28 2022 kekepower <kekepower> 0.24.3-1.mga9
+ Revision: 1786631
- Update to version 0.24.3

* Sun Feb 13 2022 kekepower <kekepower> 0.24.2-2.mga9
+ Revision: 1773832
- Rebuild for Python 3.10

* Fri Feb 04 2022 kekepower <kekepower> 0.24.2-1.mga9
+ Revision: 1771382
- Update to version 0.24.2

* Thu Jan 06 2022 kekepower <kekepower> 0.24.1-1.mga9
+ Revision: 1767083
- Update to version 0.24.1

* Tue Jan 04 2022 kekepower <kekepower> 0.24.0-1.mga9
+ Revision: 1766724
- Require rsync-devel to build
- Update to version 0.24.0

* Tue Aug 17 2021 kekepower <kekepower> 0.23.1-1.mga9
+ Revision: 1741753
- Update to version 0.23.1

* Mon Aug 16 2021 kekepower <kekepower> 0.23.0-1.mga9
+ Revision: 1741552
- Update to version 0.23.0

* Mon Aug 02 2021 kekepower <kekepower> 0.22.2-1.mga9
+ Revision: 1738593
- Update to version 0.22.2

* Sat Jul 31 2021 kekepower <kekepower> 0.22.1-1.mga9
+ Revision: 1738257
- Update to version 0.22.1

* Mon Jul 26 2021 kekepower <kekepower> 0.22.0-1.mga9
+ Revision: 1737812
- Update to version 0.22.0

* Mon Jun 28 2021 kekepower <kekepower> 0.21.2-1.mga9
+ Revision: 1734065
- Update to version 0.21.2

* Mon Jun 14 2021 kekepower <kekepower> 0.21.1-1.mga9
+ Revision: 1730648
- Update to version 0.21.1

* Sat Jun 12 2021 kekepower <kekepower> 0.21.0-1.mga9
+ Revision: 1730490
- Update to version 0.21.0

* Thu May 06 2021 kekepower <kekepower> 0.20.3-1.mga9
+ Revision: 1721904
- Update to version 0.20.3

* Wed Apr 28 2021 kekepower <kekepower> 0.20.2-1.mga9
+ Revision: 1720295
- Update to version 0.20.2

* Tue Apr 20 2021 kekepower <kekepower> 0.20.1-1.mga9
+ Revision: 1717536
- Update to version 0.20.1

* Mon Apr 19 2021 kekepower <kekepower> 0.20.0-1.mga9
+ Revision: 1717020
- Update to version 0.20.0

* Mon Mar 15 2021 kekepower <kekepower> 0.19.3-2.mga9
+ Revision: 1703135
- Rebuild with Python 3.9

* Tue Dec 22 2020 kekepower <kekepower> 0.19.3-1.mga8
+ Revision: 1662696
- Update to version 0.19.3

* Fri Nov 13 2020 kekepower <kekepower> 0.19.2-1.mga8
+ Revision: 1644901
- Update to version 0.19.2

* Tue Oct 06 2020 kekepower <kekepower> 0.19.1-1.mga8
+ Revision: 1632411
- Update to version 0.19.1

* Sun Oct 04 2020 kekepower <kekepower> 0.19.0-1.mga8
+ Revision: 1632190
- Update to version 0.19.0

* Tue Aug 11 2020 kekepower <kekepower> 0.18.3-2.mga8
+ Revision: 1613424
- Tighten up the description a little

* Tue Aug 11 2020 kekepower <kekepower> 0.18.3-1.mga8
+ Revision: 1613300
- Update to version 0.18.3

* Tue Jul 28 2020 kekepower <kekepower> 0.18.2-1.mga8
+ Revision: 1609433
- Disable tests for now
- Update to version 0.18.2

* Tue Jun 23 2020 kekepower <kekepower> 0.18.1-1.mga8
+ Revision: 1598782
- Update to version 0.18.1

* Sat Jun 20 2020 kekepower <kekepower> 0.18.0-1.mga8
+ Revision: 1598125
- Update to version 0.18.0

* Sat May 09 2020 kekepower <kekepower> 0.17.4-1.mga8
+ Revision: 1582363
- Update to version 0.17.4

* Thu Apr 23 2020 kekepower <kekepower> 0.17.3-1.mga8
+ Revision: 1571242
- Update to version 0.17.3

* Sun Mar 29 2020 kekepower <kekepower> 0.17.2-1.mga8
+ Revision: 1562144
- Update to version 0.17.2

* Tue Mar 24 2020 kekepower <kekepower> 0.17.1-1.mga8
+ Revision: 1559529
- Update to version 0.17.1

* Thu Feb 20 2020 umeabot <umeabot> 0.16.0-3.mga8
+ Revision: 1546131
- Mageia 8 Mass Rebuild
+ kekepower <kekepower>
- Bump rel

* Fri Jan 31 2020 kekepower <kekepower> 0.16.0-1.1.mga8
+ Revision: 1486120
- imported package kitty

